@@ -1,6 +1,6 @@
 /*
  * sar, sadc, sadf, mpstat and iostat common routines.
- * (C) 1999-2007 by Sebastien GODARD (sysstat <at> wanadoo.fr)
+ * (C) 1999-2007 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -55,7 +55,7 @@ unsigned int kb_shift;
 void print_version(void)
 {
    fprintf(stderr, _("sysstat version %s\n"), VERSION);
-   fprintf(stderr, "(C) Sebastien Godard (sysstat <at> wanadoo.fr)\n");
+   fprintf(stderr, "(C) Sebastien Godard (sysstat <at> orange.fr)\n");
    exit(1);
 }
 
@@ -129,7 +129,8 @@ int get_sys_cpu_nr(void)
    while ((drd = readdir(dir)) != NULL) {
 
       if (!strncmp(drd->d_name, "cpu", 3)) {
-	 sprintf(line, "%s/%s", SYSFS_DEVCPU, drd->d_name);
+	 snprintf(line, MAX_PF_NAME, "%s/%s", SYSFS_DEVCPU, drd->d_name);
+	 line[MAX_PF_NAME - 1] = '\0';
 	 if (stat(line, &buf) < 0)
 	    continue;
 	 if (S_ISDIR(buf.st_mode))
@@ -215,7 +216,8 @@ int get_dev_part_nr(char *dev_name)
    char dfile[MAX_PF_NAME], line[MAX_PF_NAME];
    int part = 0;
 
-   sprintf(dfile, "%s/%s", SYSFS_BLOCK, dev_name);
+   snprintf(dfile, MAX_PF_NAME, "%s/%s", SYSFS_BLOCK, dev_name);
+   dfile[MAX_PF_NAME - 1] = '\0';
 
    /* Open current device directory in /sys/block */
    if ((dir = opendir(dfile)) == NULL)
@@ -225,7 +227,8 @@ int get_dev_part_nr(char *dev_name)
    while ((drd = readdir(dir)) != NULL) {
       if (!strcmp(drd->d_name, ".") || !strcmp(drd->d_name, ".."))
 	 continue;
-      sprintf(line, "%s/%s/%s", dfile, drd->d_name, S_STAT);
+      snprintf(line, MAX_PF_NAME, "%s/%s/%s", dfile, drd->d_name, S_STAT);
+      line[MAX_PF_NAME - 1] = '\0';
 
       /* Try to guess if current entry is a directory containing a stat file */
       if (!access(line, R_OK))
@@ -263,7 +266,8 @@ int get_sysfs_dev_nr(int display_partitions)
    while ((drd = readdir(dir)) != NULL) {
       if (!strcmp(drd->d_name, ".") || !strcmp(drd->d_name, ".."))
 	 continue;
-      sprintf(line, "%s/%s/%s", SYSFS_BLOCK, drd->d_name, S_STAT);
+      snprintf(line, MAX_PF_NAME, "%s/%s/%s", SYSFS_BLOCK, drd->d_name, S_STAT);
+      line[MAX_PF_NAME - 1] = '\0';
 
       /* Try to guess if current entry is a directory containing a stat file */
       if (!access(line, R_OK)) {
@@ -451,7 +455,7 @@ int print_gal_header(struct tm *rectime, char *sysname, char *release, char *nod
       strftime(cur_date, sizeof(cur_date), "%x", rectime);
 
    printf("%s %s (%s) \t%s\n", sysname, release, nodename, cur_date);
-   
+
    return rc;
 }
 
@@ -602,7 +606,7 @@ unsigned long long get_interval(unsigned long long prev_uptime,
 				unsigned long long curr_uptime)
 {
    unsigned long long itv;
-   
+
    if (!prev_uptime)
       itv = curr_uptime;
    else
@@ -632,9 +636,9 @@ void readp_uptime(unsigned long long *uptime)
       return;
 
    sscanf(line, "%lu.%lu", &up_sec, &up_cent);
-   
+
    fclose(fp);
-   
+
    *uptime = up_sec * HZ + up_cent * HZ / 100;
 }
 
@@ -683,7 +687,7 @@ int readp_meminfo(struct meminf *st_mem)
    }
 
    fclose(fp);
-   
+
    return 0;
 }
 
