@@ -1,6 +1,6 @@
 /*
  * sysstat: System performance tools for Linux
- * (C) 1999-2007 by Sebastien Godard (sysstat <at> wanadoo.fr)
+ * (C) 1999-2007 by Sebastien Godard (sysstat <at> orange.fr)
  */
 
 #ifndef _COMMON_H
@@ -13,13 +13,10 @@
 
 #define MINIMUM(a,b)	((a) < (b) ? (a) : (b))
 
-#define NR_CPUS		1024
+#define NR_CPUS		16384
 
-/*
- * Size of /proc/interrupts line (at most NR_CPUS # of cpus)
- * 4 spaces for interrupt # field ; 11 spaces for each interrupt field.
- */
-#define INTERRUPTS_LINE	(4 + 11 * NR_CPUS)
+/* Size of /proc/interrupts line, CPU data excluded */
+#define INTERRUPTS_LINE	128
 
 /* Keywords */
 #define K_ISO	"ISO"
@@ -77,6 +74,13 @@ extern unsigned int hz;
 /* Number of bit shifts to convert pages to kB */
 extern unsigned int kb_shift;
 
+/*
+ * kB <-> number of pages.
+ * Page size depends on machine architecture (4 kB, 8 kB, 16 kB, 64 kB...)
+ */
+#define KB_TO_PG(k)	((k) >> kb_shift)
+#define PG_TO_KB(k)	((k) << kb_shift)
+
 /* Memory data read from /proc/meminfo */
 struct meminf {
    unsigned long frmkb;
@@ -87,7 +91,7 @@ struct meminf {
    unsigned long tlskb;
    unsigned long caskb;
 };
-   
+
 
 /*
  * Under very special circumstances, STDOUT may become unavailable,
